@@ -1,2 +1,2 @@
-import print_hello
+from print_hello import *
 from test_pppackage import agents
\ No newline at end of file
